summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/msghandler.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/kexidb/msghandler.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/kexidb/msghandler.h')
-rw-r--r--kexi/kexidb/msghandler.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kexi/kexidb/msghandler.h b/kexi/kexidb/msghandler.h
index da907c7e..c0c8c494 100644
--- a/kexi/kexidb/msghandler.h
+++ b/kexi/kexidb/msghandler.h
@@ -21,8 +21,8 @@
#define KEXIDB_MSGHANDLER_H
#include <kexidb/object.h>
-#include <qguardedptr.h>
-#include <qwidget.h>
+#include <tqguardedptr.h>
+#include <tqwidget.h>
namespace KexiDB {
@@ -38,12 +38,12 @@ namespace KexiDB {
class KEXI_DB_EXPORT MessageTitle
{
public:
- MessageTitle(KexiDB::Object* o, const QString& msg = QString::null);
+ MessageTitle(KexiDB::Object* o, const TQString& msg = TQString());
~MessageTitle();
protected:
Object* m_obj;
- QString m_prevMsgTitle;
+ TQString m_prevMsgTitle;
};
/*! A prototype for Message Handler usable
@@ -54,9 +54,9 @@ class KEXI_DB_EXPORT MessageHandler
public:
enum MessageType { Error, Sorry, Warning };
/*! Constructs mesage handler, \a parent is a widget that will be a parent
for displaying gui elements (e.g. message boxes). Can be 0 for non-gui usage. */
- MessageHandler(QWidget *parent = 0);
+ MessageHandler(TQWidget *tqparent = 0);
virtual ~MessageHandler();
/*! This method can be used to block/unblock messages.
@@ -68,12 +68,12 @@ class KEXI_DB_EXPORT MessageHandler
inline void enableMessages(bool enable) { m_enableMessages = enable; }
/*! Shows error message with \a title (it is not caption) and details. */
- virtual void showErrorMessage(const QString &title,
- const QString &details = QString::null) = 0;
+ virtual void showErrorMessage(const TQString &title,
+ const TQString &details = TQString()) = 0;
/*! Shows error message with \a msg text. Existing error message from \a obj object
is also copied, if present. */
- virtual void showErrorMessage(KexiDB::Object *obj, const QString& msg = QString::null) = 0;
+ virtual void showErrorMessage(KexiDB::Object *obj, const TQString& msg = TQString()) = 0;
/*! Interactively asks a question. For GUI version, KMessageBox class is used.
See KMessageBox documentation for explanation of the parameters.
@@ -81,15 +81,15 @@ class KEXI_DB_EXPORT MessageHandler
\a message should be i18n's string.
Value from KMessageBox::ButtonCode enum is returned.
Reimplement this. This implementation does nothing, just returns \a defaultResult. */
- virtual int askQuestion( const QString& message,
+ virtual int askQuestion( const TQString& message,
KMessageBox::DialogType dlgType, KMessageBox::ButtonCode defaultResult,
const KGuiItem &buttonYes=KStdGuiItem::yes(),
const KGuiItem &buttonNo=KStdGuiItem::no(),
- const QString &dontShowAskAgainName = QString::null,
+ const TQString &dontShowAskAgainName = TQString(),
int options = KMessageBox::Notify );
protected:
- QGuardedPtr<QWidget> m_messageHandlerParentWidget;
+ TQGuardedPtr<TQWidget> m_messageHandlerParentWidget;
bool m_enableMessages : 1;
};
@@ -54,9 +54,9 @@ class KEXI_DB_EXPORT MessageHandler
public:
enum MessageType { Error, Sorry, Warning };
- /*! Constructs mesage handler, \a parent is a widget that will be a parent
+ /*! Constructs mesage handler, \a tqparent is a widget that will be a tqparent
for displaying gui elements (e.g. message boxes). Can be 0 for non-gui usage. */